@@ -109,10 +109,16 @@ class DeviceManager(object):
             'OK' if self._hdd_dock.hwdata.wear_health_percent >= 100
             else '{}%'.format(self._hdd_dock.hwdata.wear_health_percent))
         health_status = f'{health} - {title}'
+        self.set_health(health_status)
+
+    def set_health(self, health_status):
         self._inventory_rest_client.add_health_status(
             self._hdd_id, status=health_status,
             extra_info='--{}'.format(self._author))
 
+    def set_health_with_wear(self, title):
+        self._set_health(title)
+
     def quick_erase(self):
         print('Start quick wiping')
         self._hdd_dock.quick_erase()
@@ -348,11 +354,9 @@ def registered_disk_actions(**kwargs):
             print('Server bay changed to: {}'.format(inventory.bay))
 
         elif action == '6':
-            health_status = ''
-            while len(health_status) == 0:
-                health_status = raw_input('Manual health status: ')
-            inventory_rest_client.add_health_status(
-                hdd_id, status=health_status, extra_info='--{}'.format(author))
+            health_status = (
+                raw_input('Manual health status [ONLINE]: ') or 'ONLINE')
+            manager.set_health_with_wear(health_status)
             inventory.flush()
 
         elif action == '7':
@@ -377,8 +381,14 @@ def registered_disk_actions(**kwargs):
                     hdd_dock.hwdata.power_on_hours or S_UNSET),
                 f'--{author} @ {today}',
             ]
-            labelprinter_rest_client = get_labelprinter()
-            labelprinter_rest_client.print_generic_label(lines)
+            try:
+                labelprinter_rest_client = get_labelprinter()
+                labelprinter_rest_client.print_generic_label(lines)
+            except Exception:
+                print('Would have printed:')
+                print('\n'.join('- {}'.format(line) for line in lines))
+                print()
+                raise
 
         elif action == '8':
             manager.second_best_erase()
