@@ -160,7 +160,14 @@ class SmartDataParser(object):
         # This is a percentage (the value, that is), which goes down from 100%
         # to 0% (= no health); taken from the obscurely named
         # "wear_leveling_count".
-        return int(self._get_value('wear_leveling_count', 'value'))
+        keys = ('media_wearout_indicator', 'wear_leveling_count')
+        for key in keys:
+            wear = self._get_value(key, 'value')
+            if wear is not None:
+                break
+        else:
+            raise ValueError('no wear attribute found, please file bug')
+        return int(wear)
 
     @property
     def power_on_hours(self):
